Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(963)

Unified Diff: components/offline_pages/background/request_queue.h

Issue 2228813003: Changes to fit better with the needs of the download manager. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/background/request_queue.h
diff --git a/components/offline_pages/background/request_queue.h b/components/offline_pages/background/request_queue.h
index 429c3757b89acc1cec1d65eb7cab9bc9fc604378..28c95794aac0ffe3c4e82a45ed80c78d58f474f5 100644
--- a/components/offline_pages/background/request_queue.h
+++ b/components/offline_pages/background/request_queue.h
@@ -74,14 +74,10 @@ class RequestQueue {
void UpdateRequest(const SavePageRequest& request,
const UpdateRequestCallback& callback);
// Removes the request matching the |request_id|. Result is returned through
Dmitry Titov 2016/08/10 02:52:14 This returns result from UpdateRequestResult. That
Pete Williamson 2016/08/10 21:15:25 OK, changed the callback to return an array of sta
// |callback|.
- void RemoveRequest(int64_t request_id, const UpdateRequestCallback& callback);
-
- // Removes the requests matching the |client_ids|. Results are returned
- // through |callback|.
- void RemoveRequestsByClientId(const std::vector<ClientId>& client_id,
- const UpdateRequestCallback& callback);
+ void RemoveRequests(const std::vector<int64_t>& request_ids,
+ const UpdateRequestCallback& callback);
void GetForUpdateDone(
const RequestQueue::UpdateRequestCallback& update_callback,
@@ -74,14 +74,10 @@ class RequestQueue {
void UpdateRequest(const SavePageRequest& request,
const UpdateRequestCallback& callback);
- // Removes the request matching the |request_id|. Result is returned through
+ // Removes the requests matching the |request_ids|. Result is returned through
Dmitry Titov 2016/08/10 02:52:14 This returns result from UpdateRequestResult. That
Pete Williamson 2016/08/10 21:15:25 OK, changed the callback to return an array of sta

Powered by Google App Engine
This is Rietveld 408576698